@@ -65,7 +65,7 @@ public class VersionCheckerUtil {
 
     static final int SUPPORTED_MINIMUM_REVISION = 3;
 
-    static final long MILLIS_SLEEP_TIME = 10000;
+    static final long MILLIS_SLEEP_TIME = 10_000;
 
     public void check(ConnectorFactoryFactory connectorFactoryFactory) {
         String remoteVersion = retrieveRemoteVersion(connectorFactoryFactory, MILLIS_SLEEP_TIME);
